#! /bin/sh

#
# Licensed Materials - Property of IBM
# Rational ClearCase
# (C) Copyright IBM Corp. 1999, 2003 All Rights Reserved
# US Government Users Restricted Rights -
# Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp
#

#
# Script for displaying a URL in a Web browser
#
# Usage:  display_url.sh [-viewroot <view-root-dir>] <url>
#  -viewroot must be set if running in a 'setview' AND the viewroot
#    directory is not "/view"
#  <url> may be a URL or an absolute pathname
#

# Preference: ${CLEARCASEHOME}, if set, else ${ATRIAHOME}, else hardwired.
CCASE=${CLEARCASEHOME:-${ATRIAHOME:-/opt/rational/clearcase}}

# If CCASE_MOZILLA is set, we'll use that, else if CCASE_NETSCAPE is
# defined, we'll use that.
# If neither CCASE_MOZILLA nor CCASE_NETSCAPE are defined, we will
# try mozilla first, then netscape.

# If the user hasn't chosen a browser via an EV, we can't just try
# mozilla then netscape, because we may run the browser in the
# background, and we can't reliably detect that the backgrounded
# browser was a failure to execute rather than just a completed
# browsing experience.  Instead, we search the path for an executable
# mozilla and use netscape if we can't find a mozilla.

choose_browser() {
    CCASE_BROWSER_CMD=${CCASE_MOZILLA:-${CCASE_NETSCAPE}}
    if [ "x${CCASE_BROWSER_CMD}" = "x" ] ; then

        # If user didn't specify, look for mozilla.  Use netscape if we
        # can't find mozilla.

	if type mozilla >/dev/null 2>&1 ; then
	    CCASE_BROWSER_CMD=mozilla
	else
	    CCASE_BROWSER_CMD=netscape
	fi
    fi
}

# User may also set CCASE_MOZILLA_OPT or CCASE_NETSCAPE_OPT to pass
# other flags to the browser.  We check CCASE_MOZILLA_OPT first, then
# CCASE_NETSCAPE_OPT.
# For example, to instruct netscape to use a private color map:
# % setenv CCASE_NETSCAPE_OPT "-install"

CCASE_BROWSER_OPT=${CCASE_MOZILLA_OPT:-${CCASE_NETSCAPE_OPT}}

# User may set CCASE_MOZILLA_NEW_WINDOW to ",new-window" to open a new window
# or CCASE_MOZILLA_NEW_WINDOW to ",new-tab" to open a new tab in existing
# window. (Netscape only understands ",new-window".)
# (We tack on the option to the URL in the openURL(<url>) request.)

CCASE_WINDOW_OPT=${CCASE_MOZILLA_NEW_WINDOW}

THIS_CMD=$0
VIEWROOT=/view

usage() {
    echo "Usage: $THIS_CMD [-viewroot <view-root-dir>] <url>" 1>&2
    exit 1
}

#
# Parse the command line
#

case $1 in
    -viewroot)
	shift
	if [ $# -lt 1 ] ; then
	    echo "Error: -viewroot needs view root directory as its argument" 1>&2
	    usage
	fi
	VIEWROOT=$1
	shift
	;;
esac

if [ $# != 1 ] ; then
    echo "Error: One (and only one) URL is required" 1>&2
    usage
fi

URL="$1"

#
# Construct the view tag to use as a prefix to absolute pathnames
#
SETVIEW=`${CCASE}/bin/cleartool pwv -short -setview`

VIEWTAG="${VIEWROOT}/${SETVIEW}"

#
# If the resulting $VIEWTAG directory doesn't exist, it's probably
#  because this process is not in a setview so $SETVIEW is "** NONE **".
#  In that case, don't insert anything before the pathname.
#
if [ ! -d "${VIEWTAG}" ] ; then
    VIEWTAG=""
fi

#
# Insert the view tag in front of a file's pathname
# Create an alternate pathname that doesn't have the view tag in case
# the view-root relative path is unreadable (only an issue on AIX at present)
#
ALT_DISPLAY_URL="${URL}"
case $URL in
    /*)
	DISPLAY_URL="`echo ${URL} | sed s=/=file:${VIEWTAG}/=`"
	ALT_DISPLAY_URL="`echo ${URL} | sed s=/=file:/=`"
	ALT_FILE="${URL}"
	;;
    file:/*)
        DISPLAY_URL="`echo ${URL} | sed s=file:/=file:${VIEWTAG}/=`"
	ALT_FILE="`echo ${URL} | sed s=file:/=/=`"
	;;
    *)
	# Leave the URL alone if it's not a file pathname
	DISPLAY_URL="${URL}"
esac

#
# Display the URL in the Web browser.
# If it's a file pathname, check first to see if it's really a view/VOB
# object.  If not display the alternate URL.
#
if [ $ALT_FILE ]; then
        METATYPE=`${CCASE}/bin/cleartool describe -fmt "%m" ${ALT_FILE}`
	if [ "${METATYPE}" = "**null meta type**" ]; then
		DISPLAY_URL="${ALT_DISPLAY_URL}"
	fi
fi

choose_browser

# Look for a browser process already running
if $CCASE_BROWSER_CMD $CCASE_BROWSER_OPT -remote "openURL(${DISPLAY_URL}${CCASE_WINDOW_OPT})" > /dev/null 2>&1 ; then
    exit 0		# Found a running Netscape process
else
    # Couldn't find one running so start one up
    $CCASE_BROWSER_CMD $CCASE_BROWSER_OPT "$DISPLAY_URL" &
fi
